def black():

    cor = 0x00000

    return cor

def grey11():

    cor = 0x1C1C1C

    return cor

def grey21():

    cor = 0x363636

    return cor

def grey31():

    cor = 0x4F4F4F

    return cor

def dimgray():

    cor = 0x696969

    return cor

def gray():

    cor = 0x808080

    return cor

def darkgray():

    cor = 0xA9A9A9

    return cor

def silver():

    cor = 0xC0C0C0

    return cor

def ligthgrey():

    cor = 0xD3D3D3

    return cor

def gainsboro():

    cor = 0xDCDCDC

    return cor