def cyan():

    cor = 0x00FFFF

    return cor

def darkturquoise():

    cor = 0x00CED1

    return cor

def turquoise():

    cor = 0x40E0D0

    return cor

def mediumturquoise():

    cor = 0x48D1CC

    return cor

def lightseagreen():

    cor = 0x20B2AA

    return cor

def darkcyan():

    cor = 0x008B8B

    return cor

def teal():

    cor = 0x008080

    return cor

def aquamarine():

    cor = 0x7FFFD4

    return cor

def mediumaquamarine():

    cor = 0x66CDAA

    return cor

def cadetblue():

    cor = 0x5F9EA0

    return cor