def maroon():

    cor = 0x800000

    return cor

def darkred():

    cor = 0x8B0000

    return cor

def firebrick():

    cor = 0xB22222

    return cor

def brown():

    cor = 0xA52A2A

    return cor

def salmon():

    cor = 0xFA8072

    return cor

def darksalmon():

    cor = 0xE9967A

    return cor

def lightsalmon():

    cor = 0xFFA07A

    return cor

def coral():

    cor = 0xFF7F50

    return cor

def tomato():

    cor = 0xFF6347

    return cor

def red():

    cor = 0xFF0000

    return cor