def white():

    cor = 0xFFFFFF

    return cor

def aliceblue():

    cor = 0xF0F8FF

    return cor

def ghostwhite():

    cor = 0xF8F8FF

    return cor

def snow():

    cor = 0xFFFAFA

    return cor

def seashell():

    cor = 0xFFF5EE

    return cor

def floralwhite():

    cor = 0xFFFAF0

    return cor

def whitesmoke():

    cor = 0xF5F5F5

    return cor

def beige():

    cor = 0xF5F5DC

    return cor

def oldlace():

    cor = 0xFDF5E6

    return cor

def ivory():

    cor = 0xFFFFF0

    return cor

def linen():

    cor = 0xFAF0E6

    return cor

def cornsilk():

    cor = 0xFFF8DC

    return cor

def antiquewhite():

    cor = 0xFAEBD7

    return cor

def blanchedalmond():

    cor = 0xFFEBCD

    return cor

def bisque():

    cor = 0xFFE4C4

    return cor

def lightyellow():

    cor = 0xFFFFE0

    return cor

def lemonchiffon():

    cor = 0xFFFACD

    return cor

def lightgoldenrodyellow():

    cor = 0xFAFAD2

    return cor

def papayawhip():

    cor = 0xFFEFD5

    return cor

def peachpuff():

    cor = 0xFFDAB9

    return cor

def moccasin():

    cor = 0xFFE4B5

    return cor

def palegoldenrod():

    cor = 0xEEE8AA

    return cor

def mistyrose():

    cor = 0xFFE4E1

    return cor

def lavenderblush():

    cor = 0xFFF0F5

    return cor

def lavender():

    cor = 0xE6E6FA

    return cor

def thistle():

    cor = 0xD8BFD8

    return cor

def azure():

    cor = 0xF0FFFF

    return cor

def lightcyan():

    cor = 0xE0FFFF

    return cor

def powderblue():

    cor = 0xB0E0E6

    return cor

def paleturquoise():

    cor = 0xE0FFFF

    return cor

def honeydew():

    cor = 0xF0FFF0

    return cor

def mintcream():

    cor = 0xF5FFFA

    return cor